<?php
/**
 * A helper class for cryptographical things like hashing passwords and so on
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2011 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Cryptable extends FrameworkInterface {
	/**
	 * Hashes a string with salt and returns the hash. If an old previous hash
	 * is supplied the method will use the first X chars of that hash for hashing
	 * the password. This is useful if you want to check if password is identical
	 * for authorization purposes.
	 *
	 * @param	$str		Unhashed string
	 * @param	$oldHash	A hash from previous hashed string
	 * @return	$hashed		The hashed and salted string
	 */
	function hashString ($str, $oldHash = '');

	/**
	 * Encrypt the string with fixed salt
	 *
	 * @param	$str		The unencrypted string
	 * @return	$encrypted	Encrypted string
	 */
	function encryptString ($str);

	/**
	 * Decrypt the string with fixed salt
	 *
	 * @param	$encrypted	Encrypted string
	 * @return	$str		The unencrypted string
	 */
	function decryptString ($encrypted);
}

// [EOF]
?>
